==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/FloatPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockManagerPoint } from "./DockManagerPoint";
/**
 * @hidden
 */
var FloatPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FloatPaneAction, _super);
    function FloatPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(FloatPaneAction.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.c.n = this.g;
        },
        enumerable: false,
        configurable: true
    });
    FloatPaneAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(FloatPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.d.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.d.l("location", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("location", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "f", {
        get: function () {
            var ret_ = this.d.m("width");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("width", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "e", {
        get: function () {
            var ret_ = this.d.m("height");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("height", value_);
        },
        enumerable: false,
        configurable: true
    });
    FloatPaneAction.$t = markType(FloatPaneAction, 'FloatPaneAction', PaneDragAction.$);
    return FloatPaneAction;
}(PaneDragAction));
export { FloatPaneAction };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/FloatPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockManagerPoint } from "./DockManagerPoint";
/**
 * @hidden
 */
var FloatPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FloatPaneAction, _super);
    function FloatPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(FloatPaneAction.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.c.o = this.g;
        },
        enumerable: false,
        configurable: true
    });
    FloatPaneAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(FloatPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.d.n("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.d.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.d.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("location", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("location", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "f", {
        get: function () {
            var ret_ = this.d.n("width");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("width", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatPaneAction.prototype, "e", {
        get: function () {
            var ret_ = this.d.n("height");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("height", value_);
        },
        enumerable: false,
        configurable: true
    });
    FloatPaneAction.$t = markType(FloatPaneAction, 'FloatPaneAction', PaneDragAction.$);
    return FloatPaneAction;
}(PaneDragAction));
export { FloatPaneAction };
